package
Version:
v0.267.0
Opens a new window with list of versions in this module.
Published: Aug 3, 2026
License: MIT
Opens a new window with license information.
Imports: 14
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package api implements `ofga api`: send a raw request to the OpenFGA API
using the active profile's connection and authentication.
Command is the `api` command.
New builds the api command.
func (*Command) Command ¶
Command returns the cobra command.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.