Documentation
¶
Overview ¶
Package readlimit provides bounded reads for user-controlled files, stdin, and HTTP bodies.
Index ¶
Constants ¶
const ( Config int64 = 4 << 20 Secret int64 = 1 << 20 Document int64 = 64 << 20 APIResponse int64 = 64 << 20 )
Variables ¶
This section is empty.
Functions ¶
func All ¶
All reads at most max bytes and returns an actionable error if more data is available. label identifies the input in the error message.
func SecretPermissionWarning ¶
SecretPermissionWarning reports a regular secret file that is readable or writable by group/other users. It is advisory because mounted container secrets do not always permit chmod.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.